==> biz-erp-2.2.0-20160913.123106-28-sources.jar: com/baijia/tianxiao/biz/erp/service/impl/ErpStudentCenterServiceImpl.java <==
package com.baijia.tianxiao.biz.erp.service.impl;

import java.util.List;
import java.util.Map;

import javax.annotation.Resource;

import org.apache.commons.collections.CollectionUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.baijia.tianxiao.biz.erp.dto.request.ListLessonsRequestDto;
import com.baijia.tianxiao.biz.erp.dto.response.LessonResponseDto;
import com.baijia.tianxiao.biz.erp.dto.response.ListLessonResponseDto;
import com.baijia.tianxiao.biz.erp.dto.response.studentCenter.StudentCenterCourseListDto;
import com.baijia.tianxiao.biz.erp.dto.response.studentCenter.StudentCenterInfoDto;
import com.baijia.tianxiao.biz.erp.dto.response.studentCenter.StuentCenterCourseLessonDto;
import com.baijia.tianxiao.biz.erp.service.CourseLessonService;
import com.baijia.tianxiao.biz.erp.service.ErpStudentCenterService;
import com.baijia.tianxiao.consants.UserRole;
import com.baijia.tianxiao.dal.org.dao.OrgStudentDao;
import com.baijia.tianxiao.dal.org.dao.OrgTeacherLessonDao;
import com.baijia.tianxiao.sal.comment.dto.CommentInfoDto;
import com.baijia.tianxiao.sal.comment.service.LessonCommentService;
import com.baijia.tianxiao.sal.course.dto.response.ClassLessonInfoDto;
import com.baijia.tianxiao.sal.course.dto.response.CourseListReponseDto;
import com.baijia.tianxiao.sal.course.dto.response.TeacherResponseDto;
import com.baijia.tianxiao.sal.course.service.CourseStudentService;
import com.baijia.tianxiao.sal.course.service.CourseTeacherService;
import com.baijia.tianxiao.sal.course.service.OrgCourseListService;
import com.baijia.tianxiao.sal.course.service.OrgCourseService;
import com.baijia.tianxiao.sal.course.service.SmsService;
import com.baijia.tianxiao.sal.organization.org.dto.OrgBaseInfoModel;
import com.baijia.tianxiao.sal.organization.org.service.OrgBaseService;
import com.baijia.tianxiao.sqlbuilder.dto.PageDto;
import com.google.common.base.Preconditions;
import com.google.common.collect.Lists;
import com.google.common.collect.Maps;

import lombok.NonNull;
import lombok.extern.slf4j.Slf4j;

@Slf4j
@Service
public class ErpStudentCenterServiceImpl implements ErpStudentCenterService {

    @Resource
    private CourseLessonService courseLessonService;

    @Resource
    private OrgCourseService orgCourseService;

    @Resource
    private OrgCourseListService orgCourseListService;

    @Resource
    private CourseStudentService orgCourseStudentService;

    @Resource
    private OrgBaseService orgBaseService;

    @Resource
    private LessonCommentService lessonCommentService;

    @Resource
    private CourseTeacherService courseTeacherService;

    @Resource
    private OrgTeacherLessonDao orgTeacherLessonDao;

    @Resource
    private OrgStudentDao orgStudentDao;

    @Resource
    private SmsService smsService;

    // @Override
    // public StudentCenterLessonListDto getLessonList(Long orgId, Long studentId, Date firstLessonStartTime,
    // Date lastLessonStartTime, PageDto pageDto) {
    // StudentCenterLessonListDto lessonListDto = new StudentCenterLessonListDto();
    //
    // // 设置查询参数
    // ListLessonsRequestDto params = new ListLessonsRequestDto();
    // params.setFirstLessonStartTime(firstLessonStartTime.getTime());
    // params.setLastLessonStartTime(lastLessonStartTime.getTime());
    // params.setNeedcourseName(true);
    // params.setNeedRoomName(true);
    // params.setNeedTeacherName(true);
    // params.setPageDto(pageDto);
    // params.setStudentId(studentId);
    //
    // ListLessonResponseDto dto = courseLessonService.listLessons(orgId, params);
    //
    // return lessonListDto;
    //
    // }

    @Override
    @Transactional(readOnly = true)
    public StudentCenterCourseListDto getCourseList(Long orgId, Long studentId, PageDto pageDto) {
        log.info("orgId={},studentId={},page={}", orgId, studentId, pageDto);
        OrgBaseInfoModel orgBaseInfoModel = this.orgBaseService.getOrgBaseInfoModel(orgId);
        StudentCenterCourseListDto dto = new StudentCenterCourseListDto();
        dto.setLogo(orgBaseInfoModel.getLogo());
        dto.setOrgName(orgBaseInfoModel.getShortName());
        List<CourseListReponseDto> list = orgCourseListService.getCourseList(orgId, studentId, pageDto);
        for (CourseListReponseDto courseDto : list) {
            dto.addCourseListReponseDto(courseDto);
        }
        return dto;
    }

    @Override
    @Transactional(readOnly = true)
    public StudentCenterInfoDto getInfo(@NonNull Long orgId, @NonNull Long studentId) {
        Map<String, String> map = this.orgCourseStudentService.getStudentNameAndAvatar(orgId, studentId);
        Map<String, Integer> courseLessonInfoMap =
            this.orgCourseStudentService.getStudentCourseLessonInfo(orgId, studentId);
        StudentCenterInfoDto studentCenterInfoDto = new StudentCenterInfoDto();
        studentCenterInfoDto.setAvatarUrl(map.get("avatarUrl"));
        studentCenterInfoDto.setName(map.get("name"));
        studentCenterInfoDto.setLessonToday(courseLessonInfoMap.get("lessonToday"));
        studentCenterInfoDto.setCourseCount(courseLessonInfoMap.get("courseCount"));
        studentCenterInfoDto.setCommentCount(courseLessonInfoMap.get("commentCount"));
        return studentCenterInfoDto;
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public StuentCenterCourseLessonDto getCourseLesson(Long orgId, Long courseId, Long studentId) {

        Long userId = this.orgStudentDao.getUserId(studentId);
        Preconditions.checkArgument(userId != null && userId > 0, "student not exist!");

        OrgBaseInfoModel orgBaseInfoModel = this.orgBaseService.getOrgBaseInfoModel(orgId);
        StuentCenterCourseLessonDto dto = new StuentCenterCourseLessonDto();
        dto.setLogo(orgBaseInfoModel.getLogo());
        dto.setOrgName(orgBaseInfoModel.getShortName());
        dto.setExtension(orgBaseInfoModel.getExtension());
        smsService.viewSms(orgId, courseId, userId, UserRole.STUDENT.getRole());
        ListLessonsRequestDto params = new ListLessonsRequestDto();
        params.setCourseId(courseId);
        params.setStudentId(studentId);
        params.setNeedStudentSignStatus(true);
        params.setNeedRoomName(true);
        params.setNeedTeacherName(true);
        params.setNeedcourseName(true);

        ListLessonResponseDto listResponse = courseLessonService.listLessons(orgId, params);
        dto.setLessonCount(listResponse.getList().size());

        List<Long> lessonIds = Lists.newArrayList();
        for (LessonResponseDto respDto : listResponse.getList()) {
            lessonIds.add(respDto.getLessonId());
        }
        Map<Long, Boolean> commentMap = lessonCommentService.getStudentLessonCommentMap(userId, lessonIds);
        log.debug("respose list = {}", listResponse.getList());
        for (LessonResponseDto respDto : listResponse.getList()) {
            ClassLessonInfoDto classLessonInfoDto = new ClassLessonInfoDto();
            classLessonInfoDto.setLessonId(respDto.getLessonId());
            classLessonInfoDto.setIndex(respDto.getIndex());
            classLessonInfoDto.setStartTime(respDto.getLessonStartTime());
            classLessonInfoDto.setEndTime(respDto.getLessonEndTime());
            classLessonInfoDto.setHasComment(commentMap.get(respDto.getLessonId()));
            classLessonInfoDto.setSignStatus(respDto.getSignStatus());
            classLessonInfoDto.setSignStatusStr(respDto.getSignStatusStr());
            classLessonInfoDto.setTeacherName(respDto.getTeacherName());
            classLessonInfoDto.setIsOver(respDto.getIsOver());
            classLessonInfoDto.setCourseName(respDto.getCourseName());
            classLessonInfoDto.setRoomName(respDto.getRoomName());
            dto.getLessons().add(classLessonInfoDto);
        }
        CourseListReponseDto courseListReponseDto = orgCourseService.getOrgBasicCourseInfo(orgId, courseId);
        if (courseListReponseDto != null) {
            dto.setCourseName(courseListReponseDto.getCourseName());
            dto.setCourseUrl(courseListReponseDto.getCoverUrl());
        }

        log.debug("dto = {}", dto);
        return dto;
    }

    @Override
    @Transactional(readOnly = true)
    public Map<String, Object> buildStudentCommentDetail(Long orgId, Long lessonId, Long studentId, Integer userRole) {

        Long userId = this.orgStudentDao.getUserId(studentId);
        Preconditions.checkArgument(userId != null, "student not exists!");
        if(userRole == null){
            userRole = UserRole.STUDENT.getRole();
        }
        CommentInfoDto commentInfoDto =
            lessonCommentService.getCommentDetail(lessonId, userId, orgId, userRole);
        log.debug("commentInfoDto = {}", commentInfoDto);
        Map<String, Object> map = Maps.newHashMap();
        OrgBaseInfoModel orgBaseInfoModel = this.orgBaseService.getOrgBaseInfoModel(orgId);
        map.put("orgName", orgBaseInfoModel.getShortName());
        map.put("logo", orgBaseInfoModel.getLogo());
        map.put("courseName", commentInfoDto.getCourseName());
        List<Long> teacherIds = orgTeacherLessonDao.getUserIds(lessonId, orgId);
        TeacherResponseDto teacherResponseDto = null;
        if (CollectionUtils.isNotEmpty(teacherIds)) {
            teacherResponseDto = courseTeacherService.getTeacher(teacherIds.get(0), orgId);
            if (teacherResponseDto != null) {
                map.put("teacherName", teacherResponseDto.getTeacherName());
                map.put("avatarUrl", teacherResponseDto.getAvatar());
            }
        }
        map.put("index", commentInfoDto.getIndex());
        map.put("startTime", commentInfoDto.getStartTime());
        map.put("endTime", commentInfoDto.getEndTime());
        map.put("score", commentInfoDto.getScore());
        map.put("content", commentInfoDto.getContent() == null ? "" : commentInfoDto.getContent());
        map.put("urls", commentInfoDto.getUrls() == null ? "" : commentInfoDto.getUrls());
        return map;
    }

    @Override
    @Transactional(readOnly = true)
    public Map<String, Object> buildLessonInfo(Long orgId, Long lessonId, Long studentId) {

        Map<String, Object> map = orgCourseService.buildLessonInfo(orgId, lessonId, studentId);
        OrgBaseInfoModel orgBaseInfoModel = this.orgBaseService.getOrgBaseInfoModel(orgId);
        map.put("orgName", orgBaseInfoModel.getShortName());
        map.put("logo", orgBaseInfoModel.getLogo());
        return map;

    }

}

==> biz-erp-2.27.0-20170518.072525-4-sources.jar: com/baijia/tianxiao/biz/erp/service/impl/ErpStudentCenterServiceImpl.java <==
package com.baijia.tianxiao.biz.erp.service.impl;

import com.baijia.tianxiao.biz.erp.dto.request.ListLessonsRequestDto;
import com.baijia.tianxiao.biz.erp.dto.response.LessonResponseDto;
import com.baijia.tianxiao.biz.erp.dto.response.ListLessonResponseDto;
import com.baijia.tianxiao.biz.erp.dto.response.studentCenter.StudentCenterCourseListDto;
import com.baijia.tianxiao.biz.erp.dto.response.studentCenter.StudentCenterInfoDto;
import com.baijia.tianxiao.biz.erp.dto.response.studentCenter.StuentCenterCourseLessonDto;
import com.baijia.tianxiao.biz.erp.service.CourseLessonService;
import com.baijia.tianxiao.biz.erp.service.ErpStudentCenterService;
import com.baijia.tianxiao.consants.UserRole;
import com.baijia.tianxiao.dal.org.dao.OrgStudentDao;
import com.baijia.tianxiao.dal.org.dao.OrgTeacherLessonDao;
import com.baijia.tianxiao.dal.org.po.TXAccount;
import com.baijia.tianxiao.sal.comment.dto.CommentInfoDto;
import com.baijia.tianxiao.sal.comment.service.LessonCommentService;
import com.baijia.tianxiao.sal.course.dto.response.ClassLessonInfoDto;
import com.baijia.tianxiao.sal.course.dto.response.CourseListReponseDto;
import com.baijia.tianxiao.sal.course.dto.response.TeacherResponseDto;
import com.baijia.tianxiao.sal.course.service.CourseStudentService;
import com.baijia.tianxiao.sal.course.service.CourseTeacherService;
import com.baijia.tianxiao.sal.course.service.OrgCourseListService;
import com.baijia.tianxiao.sal.course.service.OrgCourseService;
import com.baijia.tianxiao.sal.course.service.SmsService;
import com.baijia.tianxiao.sal.organization.constant.ClientType;
import com.baijia.tianxiao.sal.organization.constant.DoorgodUserRole;
import com.baijia.tianxiao.sal.organization.dto.AuthToken;
import com.baijia.tianxiao.sal.organization.org.dto.OrgBaseInfoModel;
import com.baijia.tianxiao.sal.organization.org.service.OrgBaseService;
import com.baijia.tianxiao.sal.organization.org.service.TXAccountService;
import com.baijia.tianxiao.sqlbuilder.dto.PageDto;
import com.baijia.tianxiao.util.BaseUtils;
import com.baijia.tianxiao.util.StringUtils;
import com.google.common.base.Preconditions;
import com.google.common.collect.Lists;
import com.google.common.collect.Maps;
import lombok.NonNull;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.collections.CollectionUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

@Slf4j
@Service
public class ErpStudentCenterServiceImpl implements ErpStudentCenterService {

    @Resource
    private CourseLessonService courseLessonService;

    @Resource
    private OrgCourseService orgCourseService;

    @Resource
    private OrgCourseListService orgCourseListService;

    @Resource
    private CourseStudentService orgCourseStudentService;

    @Resource
    private OrgBaseService orgBaseService;

    @Resource
    private LessonCommentService lessonCommentService;

    @Resource
    private CourseTeacherService courseTeacherService;

    @Resource
    private OrgTeacherLessonDao orgTeacherLessonDao;

    @Resource
    private OrgStudentDao orgStudentDao;

    @Resource
    private SmsService smsService;

    @Resource
    private TXAccountService txAccountService;

    // @Override
    // public StudentCenterLessonListDto getLessonList(Long orgId, Long studentId, Date firstLessonStartTime,
    // Date lastLessonStartTime, PageDto pageDto) {
    // StudentCenterLessonListDto lessonListDto = new StudentCenterLessonListDto();
    //
    // // 设置查询参数
    // ListLessonsRequestDto params = new ListLessonsRequestDto();
    // params.setFirstLessonStartTime(firstLessonStartTime.getTime());
    // params.setLastLessonStartTime(lastLessonStartTime.getTime());
    // params.setNeedcourseName(true);
    // params.setNeedRoomName(true);
    // params.setNeedTeacherName(true);
    // params.setPageDto(pageDto);
    // params.setStudentId(studentId);
    //
    // ListLessonResponseDto dto = courseLessonService.listLessons(orgId, params);
    //
    // return lessonListDto;
    //
    // }

    @Override
    @Transactional(readOnly = true)
    public StudentCenterCourseListDto getCourseList(Long orgId, Long studentId, PageDto pageDto) {
        log.info("orgId={},studentId={},page={}", orgId, studentId, pageDto);
        OrgBaseInfoModel orgBaseInfoModel = this.orgBaseService.getOrgBaseInfoModel(orgId);
        StudentCenterCourseListDto dto = new StudentCenterCourseListDto();
        dto.setLogo(orgBaseInfoModel.getLogo());
        dto.setOrgName(orgBaseInfoModel.getShortName());
        List<CourseListReponseDto> list = orgCourseListService.getCourseList(orgId, studentId, pageDto);
        for (CourseListReponseDto courseDto : list) {
            dto.addCourseListReponseDto(courseDto);
        }
        return dto;
    }

    @Override
    @Transactional(readOnly = true)
    public StudentCenterInfoDto getInfo(@NonNull Long orgId, @NonNull Long studentId) {
        Map<String, String> map = this.orgCourseStudentService.getStudentNameAndAvatar(orgId, studentId);
        Map<String, Integer> courseLessonInfoMap =
                this.orgCourseStudentService.getStudentCourseLessonInfo(orgId, studentId);
        StudentCenterInfoDto studentCenterInfoDto = new StudentCenterInfoDto();
        studentCenterInfoDto.setAvatarUrl(map.get("avatarUrl"));
        studentCenterInfoDto.setName(map.get("name"));
        studentCenterInfoDto.setLessonToday(courseLessonInfoMap.get("lessonToday"));
        studentCenterInfoDto.setCourseCount(courseLessonInfoMap.get("courseCount"));
        studentCenterInfoDto.setCommentCount(courseLessonInfoMap.get("commentCount"));

        TXAccount superAccount = txAccountService.getTXAccountByOrgId(orgId.intValue());

        List<String> accountModuleAuth = null;
        if (superAccount != null && !StringUtils.isEmpty(superAccount.getModuleAuth())) {
            accountModuleAuth = BaseUtils.strToList(superAccount.getModuleAuth(), ",");
        }
        if (CollectionUtils.isNotEmpty(accountModuleAuth) && accountModuleAuth.contains(String.valueOf(ClientType.HW.getCode()))) {
            studentCenterInfoDto.setHwCenter(AuthToken.assignMentStudentToken(orgId, studentId, map.get("name"), DoorgodUserRole.STUDENT.getRole(), ClientType.HW));
        }
        if (CollectionUtils.isNotEmpty(accountModuleAuth) && accountModuleAuth.contains(String.valueOf(ClientType.EXAM.getCode()))) {
            studentCenterInfoDto.setExamCenter(AuthToken.assignMentStudentToken(orgId, studentId, map.get("name"), DoorgodUserRole.STUDENT.getRole(), ClientType.EXAM));
        }
        if (CollectionUtils.isNotEmpty(accountModuleAuth) && accountModuleAuth.contains(String.valueOf(ClientType.GRADE.getCode()))) {
            studentCenterInfoDto.setGradeCenter(AuthToken.assignMentStudentToken(orgId, studentId, map.get("name"), DoorgodUserRole.STUDENT.getRole(), ClientType.GRADE));
        }
        return studentCenterInfoDto;
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public StuentCenterCourseLessonDto getCourseLesson(Long orgId, Long courseId, Long studentId) {

        Long userId = this.orgStudentDao.getUserId(studentId);
        Preconditions.checkArgument(userId != null && userId > 0, "student not exist!");

        OrgBaseInfoModel orgBaseInfoModel = this.orgBaseService.getOrgBaseInfoModel(orgId);
        StuentCenterCourseLessonDto dto = new StuentCenterCourseLessonDto();
        dto.setLogo(orgBaseInfoModel.getLogo());
        dto.setOrgName(orgBaseInfoModel.getShortName());
        dto.setExtension(orgBaseInfoModel.getExtension());
        smsService.viewSms(orgId, courseId, userId, UserRole.STUDENT.getRole());
        ListLessonsRequestDto params = new ListLessonsRequestDto();
        params.setCourseId(courseId);
        params.setStudentId(studentId);
        params.setNeedStudentSignStatus(true);
        params.setNeedRoomName(true);
        params.setNeedTeacherName(true);
        params.setNeedcourseName(true);

        ListLessonResponseDto listResponse = courseLessonService.listLessons(orgId, params, false);
        dto.setLessonCount(listResponse.getList().size());

        List<Long> lessonIds = Lists.newArrayList();
        for (LessonResponseDto respDto : listResponse.getList()) {
            lessonIds.add(respDto.getLessonId());
        }
        Map<Long, Boolean> commentMap = lessonCommentService.getStudentLessonCommentMap(userId, lessonIds);
        log.debug("respose list = {}", listResponse.getList());
        for (LessonResponseDto respDto : listResponse.getList()) {
            ClassLessonInfoDto classLessonInfoDto = new ClassLessonInfoDto();
            classLessonInfoDto.setLessonId(respDto.getLessonId());
            classLessonInfoDto.setIndex(respDto.getIndex());
            classLessonInfoDto.setStartTime(respDto.getLessonStartTime());
            classLessonInfoDto.setEndTime(respDto.getLessonEndTime());
            classLessonInfoDto.setHasComment(commentMap.get(respDto.getLessonId()));
            classLessonInfoDto.setSignStatus(respDto.getSignStatus());
            classLessonInfoDto.setSignStatusStr(respDto.getSignStatusStr());
            classLessonInfoDto.setTeacherName(respDto.getTeacherName());
            classLessonInfoDto.setIsOver(respDto.getIsOver());
            classLessonInfoDto.setCourseName(respDto.getCourseName());
            classLessonInfoDto.setRoomName(respDto.getRoomName());
            classLessonInfoDto.setLessonName(respDto.getLessonName());
            dto.getLessons().add(classLessonInfoDto);
        }
        CourseListReponseDto courseListReponseDto = orgCourseService.getOrgBasicCourseInfo(orgId, courseId);
        if (courseListReponseDto != null) {
            dto.setCourseName(courseListReponseDto.getCourseName());
            dto.setCourseUrl(courseListReponseDto.getCoverUrl());
        }

        log.debug("dto = {}", dto);
        return dto;
    }

    @Override
    @Transactional(readOnly = true)
    public Map<String, Object> buildStudentCommentDetail(Long orgId, Long lessonId, Long studentId, Integer userRole) {

        Long userId = this.orgStudentDao.getUserId(studentId);
        Preconditions.checkArgument(userId != null, "student not exists!");
        if (userRole == null) {
            userRole = UserRole.STUDENT.getRole();
        }
        CommentInfoDto commentInfoDto =
                lessonCommentService.getCommentDetail(lessonId, userId, orgId, userRole);
        log.debug("commentInfoDto = {}", commentInfoDto);
        Map<String, Object> map = Maps.newHashMap();
        OrgBaseInfoModel orgBaseInfoModel = this.orgBaseService.getOrgBaseInfoModel(orgId);
        map.put("orgName", orgBaseInfoModel.getShortName());
        map.put("logo", orgBaseInfoModel.getLogo());
        map.put("courseName", commentInfoDto.getCourseName());
        List<Long> teacherIds = orgTeacherLessonDao.getUserIds(lessonId, orgId);
        TeacherResponseDto teacherResponseDto = null;
        if (CollectionUtils.isNotEmpty(teacherIds)) {
            teacherResponseDto = courseTeacherService.getTeacher(teacherIds.get(0), orgId);
            if (teacherResponseDto != null) {
                map.put("teacherName", teacherResponseDto.getTeacherName());
                map.put("avatarUrl", teacherResponseDto.getAvatar());
            }
        }
        map.put("index", commentInfoDto.getIndex());
        map.put("startTime", commentInfoDto.getStartTime());
        map.put("endTime", commentInfoDto.getEndTime());
        map.put("score", commentInfoDto.getScore());
        map.put("content", commentInfoDto.getContent() == null ? "" : commentInfoDto.getContent());
        map.put("urls", commentInfoDto.getUrls() == null ? "" : commentInfoDto.getUrls());
        return map;
    }

    @Override
    @Transactional(readOnly = true)
    public Map<String, Object> buildLessonInfo(Long orgId, Long lessonId, Long studentId) {

        Map<String, Object> map = orgCourseService.buildLessonInfo(orgId, lessonId, studentId);
        OrgBaseInfoModel orgBaseInfoModel = this.orgBaseService.getOrgBaseInfoModel(orgId);
        map.put("orgName", orgBaseInfoModel.getShortName());
        map.put("logo", orgBaseInfoModel.getLogo());
        map.put("extension", orgBaseInfoModel.getExtension());
        return map;

    }

}
